==> zio-aws-mediapackage_3-5.17.129.2-sources.jar: zio/aws/mediapackage/model/DescribeOriginEndpointRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeOriginEndpointRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest = {
    import DescribeOriginEndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.DescribeOriginEndpointRequest.ReadOnly =
    zio.aws.mediapackage.model.DescribeOriginEndpointRequest
      .wrap(buildAwsValue())
}
object DescribeOriginEndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DescribeOriginEndpointRequest =
      zio.aws.mediapackage.model.DescribeOriginEndpointRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
  ) extends zio.aws.mediapackage.model.DescribeOriginEndpointRequest.ReadOnly {
    override val id: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
  ): zio.aws.mediapackage.model.DescribeOriginEndpointRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackage_3-5.17.130.7-sources.jar: zio/aws/mediapackage/model/DescribeOriginEndpointRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeOriginEndpointRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest = {
    import DescribeOriginEndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.DescribeOriginEndpointRequest.ReadOnly =
    zio.aws.mediapackage.model.DescribeOriginEndpointRequest
      .wrap(buildAwsValue())
}
object DescribeOriginEndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DescribeOriginEndpointRequest =
      zio.aws.mediapackage.model.DescribeOriginEndpointRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
  ) extends zio.aws.mediapackage.model.DescribeOriginEndpointRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeOriginEndpointRequest
  ): zio.aws.mediapackage.model.DescribeOriginEndpointRequest.ReadOnly =
    new Wrapper(impl)
}
